{% extends "base.html" %}

{% block content %}

<h1 style="margin: 30px">{% if object %}Edit {{object_verbose_name}}{% else %}Create {{object_verbose_name}}{% endif%}</h1>

<div style="margin: 30px">
<form method="POST" action=".">
{% csrf_token %}
{{ form }}
<input type="submit" class="btn btn-primary" value="Save">
</form>
</div>
{% endblock %}
